==> cdk-cx-api-1.15.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/cxapi/CloudArtifact.java <==
package software.amazon.awscdk.cxapi;

/**
 * Represents an artifact within a cloud assembly.
 * 
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.19.0 (build 7c562bc)", date = "2019-10-28T12:12:23.566Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.cxapi.$Module.class, fqn = "@aws-cdk/cx-api.CloudArtifact")
public class CloudArtifact extends software.amazon.jsii.JsiiObject {

    protected CloudArtifact(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected CloudArtifact(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * EXPERIMENTAL
     * 
     * @param assembly This parameter is required.
     * @param id This parameter is required.
     * @param manifest This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public CloudArtifact(final software.amazon.awscdk.cxapi.CloudAssembly assembly, final java.lang.String id, final software.amazon.awscdk.cxapi.ArtifactManifest manifest) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        this.setObjRef(software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(assembly, "assembly is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(manifest, "manifest is required") }));
    }

    /**
     * Returns a subclass of `CloudArtifact` based on the artifact type defined in the artifact manifest.
     * 
     * EXPERIMENTAL
     * 
     * @return the `CloudArtifact` that matches the artifact type or `undefined` if it's an artifact type that is unrecognized by this module.
     * @param assembly The cloud assembly from which to load the artifact. This parameter is required.
     * @param id The artifact ID. This parameter is required.
     * @param artifact The artifact manifest. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static software.amazon.awscdk.cxapi.CloudArtifact fromManifest(final software.amazon.awscdk.cxapi.CloudAssembly assembly, final java.lang.String id, final software.amazon.awscdk.cxapi.ArtifactManifest artifact) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.cxapi.CloudArtifact.class, "fromManifest", software.amazon.awscdk.cxapi.CloudArtifact.class, new Object[] { java.util.Objects.requireNonNull(assembly, "assembly is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(artifact, "artifact is required") });
    }

    /**
     * EXPERIMENTAL
     * 
     * @return all the metadata entries of a specific type in this artifact.
     * @param type This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.util.List<software.amazon.awscdk.cxapi.MetadataEntryResult> findMetadataByType(final java.lang.String type) {
        return java.util.Collections.unmodifiableList(this.jsiiCall("findMetadataByType", java.util.List.class, new Object[] { java.util.Objects.requireNonNull(type, "type is required") }));
    }

    /**
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public software.amazon.awscdk.cxapi.CloudAssembly getAssembly() {
        return this.jsiiGet("assembly", software.amazon.awscdk.cxapi.CloudAssembly.class);
    }

    /**
     * Returns all the artifacts that this artifact depends on.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.util.List<software.amazon.awscdk.cxapi.CloudArtifact> getDependencies() {
        return java.util.Collections.unmodifiableList(this.jsiiGet("dependencies", java.util.List.class));
    }

    /**
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.lang.String getId() {
        return this.jsiiGet("id", java.lang.String.class);
    }

    /**
     * The artifact's manifest.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public software.amazon.awscdk.cxapi.ArtifactManifest getManifest() {
        return this.jsiiGet("manifest", software.amazon.awscdk.cxapi.ArtifactManifest.class);
    }

    /**
     * The set of messages extracted from the artifact's metadata.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.util.List<software.amazon.awscdk.cxapi.SynthesisMessage> getMessages() {
        return java.util.Collections.unmodifiableList(this.jsiiGet("messages", java.util.List.class));
    }
}

==> cdk-cx-api-1.16.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/cxapi/CloudArtifact.java <==
package software.amazon.awscdk.cxapi;

/**
 * Represents an artifact within a cloud assembly.
 * 
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.20.2 (build faba0be)", date = "2019-11-11T17:17:46.972Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.cxapi.$Module.class, fqn = "@aws-cdk/cx-api.CloudArtifact")
public class CloudArtifact extends software.amazon.jsii.JsiiObject {

    protected CloudArtifact(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected CloudArtifact(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * EXPERIMENTAL
     * 
     * @param assembly This parameter is required.
     * @param id This parameter is required.
     * @param manifest This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    protected CloudArtifact(final software.amazon.awscdk.cxapi.CloudAssembly assembly, final java.lang.String id, final software.amazon.awscdk.cxapi.ArtifactManifest manifest) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(assembly, "assembly is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(manifest, "manifest is required") });
    }

    /**
     * Returns a subclass of `CloudArtifact` based on the artifact type defined in the artifact manifest.
     * 
     * EXPERIMENTAL
     * 
     * @return the `CloudArtifact` that matches the artifact type or `undefined` if it's an artifact type that is unrecognized by this module.
     * @param assembly The cloud assembly from which to load the artifact. This parameter is required.
     * @param id The artifact ID. This parameter is required.
     * @param artifact The artifact manifest. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static software.amazon.awscdk.cxapi.CloudArtifact fromManifest(final software.amazon.awscdk.cxapi.CloudAssembly assembly, final java.lang.String id, final software.amazon.awscdk.cxapi.ArtifactManifest artifact) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.cxapi.CloudArtifact.class, "fromManifest", software.amazon.awscdk.cxapi.CloudArtifact.class, new Object[] { java.util.Objects.requireNonNull(assembly, "assembly is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(artifact, "artifact is required") });
    }

    /**
     * EXPERIMENTAL
     * 
     * @return all the metadata entries of a specific type in this artifact.
     * @param type This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.util.List<software.amazon.awscdk.cxapi.MetadataEntryResult> findMetadataByType(final java.lang.String type) {
        return java.util.Collections.unmodifiableList(this.jsiiCall("findMetadataByType", java.util.List.class, new Object[] { java.util.Objects.requireNonNull(type, "type is required") }));
    }

    /**
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public software.amazon.awscdk.cxapi.CloudAssembly getAssembly() {
        return this.jsiiGet("assembly", software.amazon.awscdk.cxapi.CloudAssembly.class);
    }

    /**
     * Returns all the artifacts that this artifact depends on.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.util.List<software.amazon.awscdk.cxapi.CloudArtifact> getDependencies() {
        return java.util.Collections.unmodifiableList(this.jsiiGet("dependencies", java.util.List.class));
    }

    /**
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.lang.String getId() {
        return this.jsiiGet("id", java.lang.String.class);
    }

    /**
     * The artifact's manifest.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public software.amazon.awscdk.cxapi.ArtifactManifest getManifest() {
        return this.jsiiGet("manifest", software.amazon.awscdk.cxapi.ArtifactManifest.class);
    }

    /**
     * The set of messages extracted from the artifact's metadata.
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public java.util.List<software.amazon.awscdk.cxapi.SynthesisMessage> getMessages() {
        return java.util.Collections.unmodifiableList(this.jsiiGet("messages", java.util.List.class));
    }
}
